%ifarch s390 s390x
%global build_openmpi 0
%endif
%{!?build_openmpi:%global build_openmpi 1}
%{!?build_mpich2:%global build_mpich2 1}
%global pv_maj 3
%global pv_min 14
%global pv_patch 0
%global pv_majmin %{pv_maj}.%{pv_min}
#global rcver -RC2

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

Name:           paraview
Version:        %{pv_majmin}.%{pv_patch}
Release:        2%{?dist}
Summary:        Parallel visualization application

Group:          Applications/Engineering
License:        BSD
URL:            http://www.paraview.org/
Source0:        http://www.paraview.org/files/v%{pv_majmin}/ParaView-%{version}%{?rcver}-Source.tar.gz
Source1:        paraview_22x22.png
Source2:        paraview.xml
#Add some needed includes
Patch1:         paraview-3.8.0-include.patch
#Patch to vtk (from vtk package) to use system libraries
Patch2:         vtk-5.6.1-system.patch
#Patch to build with gcc 4.7
#Reported upstream: http://paraview.org/Bug/view.php?id=12881
Patch3:         paraview-gcc47.patch
#Reported upstream: http://public.kitware.com/mantis/view.php?id=7023
Patch7:         paraview-3.2.2-hdf5.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  cmake
%if %{build_openmpi}
BuildRequires:  openmpi-devel
%endif
%if %{build_mpich2}
BuildRequires:  mpich2-devel
%endif
BuildRequires:  qt-devel
BuildRequires:  qt-assistant-adp-devel
BuildRequires:  qt-webkit-devel
BuildRequires:  mesa-libOSMesa-devel
BuildRequires:  python-devel, tk-devel, hdf5-devel
BuildRequires:  freetype-devel, libtiff-devel, zlib-devel
BuildRequires:  expat-devel
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen, graphviz
BuildRequires:  readline-devel
BuildRequires:  openssl-devel
BuildRequires:  gnuplot
BuildRequires:  wget
BuildRequires:  boost-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtheora-devel
BuildRequires:  libxml2-devel
Requires:       hdf5 = %{_hdf5_version}
Requires:       %{name}-data = %{version}-%{release}
Requires:       %{name}-doc = %{version}-%{release}
Requires(post):   desktop-file-utils
Requires(postun): desktop-file-utils
Obsoletes:      paraview-demos < %{version}-%{release}
Provides:       paraview-demos = %{version}-%{release}
Obsoletes:      paraview-doc < %{version}-%{release}
Provides:       paraview-doc = %{version}-%{release}

#-- Plugin: EyeDomeLighting disabled
#-- Plugin: Manta ray traced rendering disabled - Requires Manta
#-- Plugin: NetDMF file format reader disabled - Requires NetDMF
#-- Plugin: Override time requests disabled
#-- Plugin: Plugin for creating python coprocessing scripts disabled
#-- Plugin: Plugin to read NCAR VDF files disabled - Requires Vapor
#-- Plugin: Reader for *.bp files based on Adios disabled
#-- Plugin: Virtual Reality Private Network (VRPN) tracker disabled - Requires VRPN
#-- Plugin: Virtual Reality User Interface (VRUI) tracker disabled
#-- Plugin: Virtual Reality User Interface (VRUI) tracker enabled
#CMake Error at Plugins/VRUI/CMakeLists.txt:7 (FIND_PACKAGE):
#  Could not find module FindParaView.cmake or a configuration file for
#  package ParaView.
#  Adjust CMAKE_MODULE_PATH to find FindParaView.cmake or set ParaView_DIR to
#  the directory containing a CMake configuration file for ParaView.  The file
#  will have one of the following names:
#    ParaViewConfig.cmake
#    paraview-config.cmake
%define paraview_cmake_options \\\
        -DCMAKE_CXX_COMPILER:FILEPATH=$CXX \\\
        -DCMAKE_C_COMPILER:FILEPATH=$CC \\\
        -DTCL_LIBRARY:PATH=tcl \\\
        -DTK_LIBRARY:PATH=tk \\\
        -DPARAVIEW_BUILD_PLUGIN_AdiosReader:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_CoProcessingScriptGenerator:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_EyeDomeLighting:BOOL=ON \\\
        -DPARAVIEW_BUILD_PLUGIN_ForceTime:BOOL=ON \\\
        -DPARAVIEW_ENABLE_PYTHON:BOOL=ON \\\
        -DPARAVIEW_INSTALL_THIRD_PARTY_LIBRARIES:BOOL=OFF \\\
        -DPARAVIEW_INSTALL_DEVELOPMENT:BOOL=ON \\\
        -DVTK_OPENGL_HAS_OSMESA:BOOL=ON \\\
        -DVTK_USE_BOOST:BOOL=ON \\\
        -DVTK_USE_INFOVIS:BOOL=OFF \\\
        -DVTK_USE_N_WAY_ARRAYS:BOOL=ON \\\
        -DVTK_USE_OGGTHEORA_ENCODER:BOOL=ON \\\
        -DVTK_USE_SYSTEM_LIBRARIES=ON \\\
        -DVTK_USE_SYSTEM_LIBPROJ4=OFF \\\
        -DXDMF_WRAP_PYTHON:BOOL=ON \\\
        -DBUILD_DOCUMENTATION:BOOL=ON \\\
        -DBUILD_EXAMPLES:BOOL=ON

%description
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

NOTE: The version in this package has NOT been compiled with MPI support.
%if %{build_openmpi}
Install the paraview-openmpi package to get a version compiled with openmpi.
%endif
%if %{build_mpich2}
Install the paraview-mpich2 package to get a version compiled with mpich2.
%endif


%package        data
Summary:        Data files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    data
%{summary}.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%package        doc
Summary:        Documentation files for ParaView
Group:          Applications/Engineering
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
%{summary}.


%if %{build_openmpi}
%package        openmpi
Summary:        Parallel visualization application
Group:          Applications/Engineering
Requires:       %{name}-data = %{version}-%{release}
Requires:       openmpi
Obsoletes:      %{name}-mpi < %{version}-%{release}
Provides:       %{name}-mpi = %{version}-%{release}

%description    openmpi
This package contains copies of the ParaView server binaries compiled with
OpenMPI.  These are named pvserver_openmpi, pvbatch_openmpi, etc.

You will need to load the openmpi-%{_arch} module to setup your path properly.


%package        openmpi-devel
Summary:        Development files for %{name}-openmpi
Group:          Development/Libraries
Requires:       %{name}-openmpi%{?_isa} = %{version}-%{release}

%description    openmpi-devel
The %{name}-openmpi-devel package contains libraries and header files for
developing applications that use %{name}-openmpi.
%endif

%if %{build_mpich2}
%package        mpich2
Summary:        Parallel visualization application
Group:          Applications/Engineering
Requires:       %{name}-data = %{version}-%{release}
Requires:       mpich2

%description    mpich2
This package contains copies of the ParaView server binaries compiled with
mpich2.  These are named pvserver_mpich2, pvbatch_mpich2, etc.

You will need to load the mpich2-%{_arch} module to setup your path properly.


%package        mpich2-devel
Summary:        Development files for %{name}-mpich2
Group:          Development/Libraries
Requires:       %{name}-mpich2%{?_isa} = %{version}-%{release}

%description    mpich2-devel
The %{name}-mpich2-devel package contains libraries and header files for
developing applications that use %{name}-mpich2.
%endif


%prep
%setup -q -n ParaView-%{version}%{?rcver}-Source
%patch1 -p1 -b .include
%patch2 -p0 -b .system
%patch3 -p1 -b .gcc47
%patch7 -p1 -b .hdf5
#Remove included hdf5 just to be sure
rm -r VTK/Utilities/vtkhdf5


%build
export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
mkdir fedora
pushd fedora
%cmake .. \
        -DPV_INSTALL_INCLUDE_DIR:PATH=include/paraview \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/paraview \
        %{paraview_cmake_options}
make VERBOSE=1 %{?_smp_mflags}
popd
%if %{build_openmpi}
mkdir fedora-openmpi
pushd fedora-openmpi
%{_openmpi_load}
%cmake .. \
        -DPV_INSTALL_BIN_DIR:PATH=%{_lib}/openmpi/bin \
        -DPV_INSTALL_INCLUDE_DIR:PATH=%{_lib}/openmpi/include/paraview \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/openmpi/lib/paraview \
        -DPARAVIEW_USE_MPI:BOOL=ON \
        -DICET_BUILD_TESTING:BOOL=ON \
        -DMPI_COMPILER:FILEPATH=%{_libdir}/openmpi/bin/mpicxx \
        %{paraview_cmake_options}
# Fixup forward paths
sed -i -e 's,../%{_lib}/openmpi,..,' `find -name \*-forward.c`
make VERBOSE=1 %{?_smp_mflags}
%{_openmpi_unload}
popd
%endif
%if %{build_mpich2}
mkdir fedora-mpich2
pushd fedora-mpich2
%{_mpich2_load}
%cmake .. \
        -DPV_INSTALL_BIN_DIR:PATH=%{_lib}/mpich2/bin \
        -DPV_INSTALL_INCLUDE_DIR:PATH=%{_lib}/mpich2/include/paraview \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/mpich2/lib/paraview \
        -DPARAVIEW_USE_MPI:BOOL=ON \
        -DICET_BUILD_TESTING:BOOL=ON \
        -DMPI_COMPILER:FILEPATH=%{_libdir}/mpich2/bin/mpicxx \
        %{paraview_cmake_options}
# Fixup forward paths
sed -i -e 's,../%{_lib}/mpich2,..,' `find -name \*-forward.c`
make VERBOSE=1 %{?_smp_mflags}
%{_mpich2_unload}
popd
%endif


%install
rm -rf $RPM_BUILD_ROOT

#Fix permissions
find . \( -name \*.txt -o -name \*.xml -o -name '*.[ch]' -o -name '*.[ch][px][px]' \) -print0 | xargs -0 chmod -x

# Create some needed directories
install -d $RPM_BUILD_ROOT%{_datadir}/applications
install -d $RPM_BUILD_ROOT%{_datadir}/pixmaps
install -m644 %SOURCE1 $RPM_BUILD_ROOT%{_datadir}/pixmaps
install -d $RPM_BUILD_ROOT%{_datadir}/mime/packages
install -m644 %SOURCE2 $RPM_BUILD_ROOT%{_datadir}/mime/packages

%if %{build_openmpi}
# Install openmpi version
pushd fedora-openmpi
make install DESTDIR=$RPM_BUILD_ROOT

#Cleanup %{_bindir}
pushd $RPM_BUILD_ROOT%{_libdir}/openmpi/bin
#Don't need mpi versions of these
rm paraview pvblot pvpython kw* vtk*
#Move the remaining mpi binaries out of the way
for f in pvbatch pvdataserver pvrenderserver pvserver smTestDriver
do
   mv $f ${f}_openmpi
done
popd

#Remove mpi copy of man pages
rm -rf $RPM_BUILD_ROOT%{_mandir}

# Move python files by hand for now
cp -rp $RPM_BUILD_ROOT%{_libdir}/openmpi/bin/Python/vtk $RPM_BUILD_ROOT%{_libdir}/openmpi/lib/paraview/site-packages/
rm -rf $RPM_BUILD_ROOT%{_libdir}/openmpi/bin/Python

#Install vtk*Python.so by hand for now
mv $RPM_BUILD_ROOT%{_libdir}/openmpi/lib/paraview/vtk*Python.so $RPM_BUILD_ROOT%{_libdir}/openmpi/lib/paraview/site-packages/paraview/vtk/
mv $RPM_BUILD_ROOT%{_libdir}/openmpi/lib/paraview/site-packages/paraview/vtk/vtkPV*Python.so $RPM_BUILD_ROOT%{_libdir}/openmpi/lib/paraview/site-packages/paraview/
popd
%endif

%if %{build_mpich2}
# Install mpich2 version
pushd fedora-mpich2
make install DESTDIR=$RPM_BUILD_ROOT

#Cleanup %{_bindir}
pushd $RPM_BUILD_ROOT%{_libdir}/mpich2/bin
#Don't need mpi versions of these
rm paraview pvblot pvpython kw* vtk*
#Move the remaining mpi binaries out of the way
for f in pvbatch pvdataserver pvrenderserver pvserver smTestDriver
do
   mv $f ${f}_mpich2
done
popd

#Remove mpi copy of man pages
rm -rf $RPM_BUILD_ROOT%{_mandir}

# Move python files by hand for now
cp -rp $RPM_BUILD_ROOT%{_libdir}/mpich2/bin/Python/vtk $RPM_BUILD_ROOT%{_libdir}/mpich2/lib/paraview/site-packages/
rm -rf $RPM_BUILD_ROOT%{_libdir}/mpich2/bin/Python

#Install vtk*Python.so by hand for now
mv $RPM_BUILD_ROOT%{_libdir}/mpich2/lib/paraview/vtk*Python.so $RPM_BUILD_ROOT%{_libdir}/mpich2/lib/paraview/site-packages/paraview/vtk/
mv $RPM_BUILD_ROOT%{_libdir}/mpich2/lib/paraview/site-packages/paraview/vtk/vtkPV*Python.so $RPM_BUILD_ROOT%{_libdir}/mpich2/lib/paraview/site-packages/paraview/
popd
%endif

#Install the normal version
pushd fedora
make install DESTDIR=$RPM_BUILD_ROOT

#Create desktop file
cat > paraview.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=ParaView Viewer
GenericName=Data Viewer
Comment=ParaView allows viewing of large data sets
Type=Application
Terminal=false
Icon=paraview_22x22
MimeType=application/x-paraview;
Categories=Application;Graphics;
Exec=paraview
EOF

desktop-file-install --vendor=fedora \
       --add-category=X-Fedora \
       --dir %{buildroot}%{_datadir}/applications/ \
       paraview.desktop

# Move python files by hand for now
cp -rp $RPM_BUILD_ROOT%{_bindir}/Python/vtk $RPM_BUILD_ROOT%{_libdir}/paraview/site-packages/
rm -rf $RPM_BUILD_ROOT%{_bindir}/Python

#Install vtk*Python.so by hand for now
mv $RPM_BUILD_ROOT%{_libdir}/paraview/vtk*Python.so $RPM_BUILD_ROOT%{_libdir}/paraview/site-packages/paraview/vtk/
mv $RPM_BUILD_ROOT%{_libdir}/paraview/site-packages/paraview/vtk/vtkPV*Python.so $RPM_BUILD_ROOT%{_libdir}/paraview/site-packages/paraview/

#Cleanup vtk binaries
rm $RPM_BUILD_ROOT%{_bindir}/vtk*
popd


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
update-desktop-database &> /dev/null ||:


%postun
/sbin/ldconfig
update-desktop-database &> /dev/null ||:


#Handle changing from directory to file
%pre
if [ -d %{_libdir}/paraview/paraview ]
then
  rm -r %{_libdir}/paraview/paraview
fi


%post   data
update-mime-database %{_datadir}/mime &> /dev/null || :

%postun data
update-mime-database %{_datadir}/mime &> /dev/null || :


%files
%doc License_v1.2.txt
%{_bindir}/paraview
%{_bindir}/pvbatch
%{_bindir}/pvblot
%{_bindir}/pvdataserver
%{_bindir}/pvpython
%{_bindir}/pvrenderserver
%{_bindir}/pvserver
%{_bindir}/smTestDriver
%{_libdir}/paraview/

%files data
%{_datadir}/applications/fedora-paraview.desktop
%{_datadir}/pixmaps/paraview_22x22.png
%{_datadir}/mime/packages/paraview.xml

%files devel
%{_bindir}/kwProcessXML
%{_includedir}/paraview/
%{_datadir}/doc/paraview-%{pv_majmin}/


%if %{build_openmpi}
%files openmpi
%doc License_v1.2.txt
%{_libdir}/openmpi/bin/pvbatch_openmpi
%{_libdir}/openmpi/bin/pvdataserver_openmpi
%{_libdir}/openmpi/bin/pvrenderserver_openmpi
%{_libdir}/openmpi/bin/pvserver_openmpi
%{_libdir}/openmpi/bin/smTestDriver_openmpi
%{_libdir}/openmpi/lib/paraview

%files openmpi-devel
%{_libdir}/openmpi/include/paraview/
%endif


%if %{build_mpich2}
%files mpich2
%doc License_v1.2.txt
%{_libdir}/mpich2/bin/pvbatch_mpich2
%{_libdir}/mpich2/bin/pvdataserver_mpich2
%{_libdir}/mpich2/bin/pvrenderserver_mpich2
%{_libdir}/mpich2/bin/pvserver_mpich2
%{_libdir}/mpich2/bin/smTestDriver_mpich2
%{_libdir}/mpich2/lib/paraview

%files mpich2-devel
%{_libdir}/mpich2/include/paraview/
%endif


%changelog
* Wed Feb 29 2012 Orion Poplawski <orion@cora.nwra.com> - 3.14.0-2
- Add patch to make vtk use system libraries

* Wed Feb 29 2012 Orion Poplawski <orion@cora.nwra.com> - 3.14.0-1
- Update to 3.14.0
- Rebase gcc47 patch
- Try to handle python install problems manually

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.12.0-8
- Rebuilt for c++ ABI breakage

* Thu Jan 27 2012 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-7
- Build with gcc 4.7
- Add patch to support gcc 4.7
- Build with new libOSMesa

* Tue Dec 27 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-3.4
- Rebuild with proper hdf5

* Tue Dec 27 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-3.3
- vtkPV*Python.so needs to go into the paraview python dir
- Drop chrpath

* Fri Dec 16 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-3.2
- Oops, install vtk*Python.so, not libvtk*Python.so

* Mon Dec 12 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-3
- Install more libvtk libraries by hand and manually remove rpath

* Thu Dec 1 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-2
- Enable PARAVIEW_INSTALL_DEVELOPMENT and re-add -devel sub-package
- Install libvtk*Python.so by hand for now

* Thu Nov 10 2011 Orion Poplawski <orion@cora.nwra.com> - 3.12.0-1
- Update to 3.12.0

* Fri Oct 28 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.1-6
- Fixup forward paths for mpi versions (bug #748221)

* Thu Jun 23 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.1-5
- Add BR qtwebkit-devel, fixes FTBS bug 716151

* Tue May 17 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.1-4
- Rebuild for hdf5 1.8.7

* Tue Apr 19 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.1-3
- No need to move python install with 3.10.1

* Tue Apr 19 2011 Dan Horák <dan[at]danny.cz> - 3.10.1-2
- no openmpi on s390(x)

* Mon Apr 18 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.1-1
- Update to 3.10.1
- Drop build patch fixed upstream

* Mon Apr 4 2011 Orion Poplawski <orion@cora.nwra.com> - 3.10.0-1
- Update to 3.10.0
- Drop lib and py27 patches fixed upstream
- Add patch for gcc 4.6.0 support
- Update system hdf5 handling
- Cleanup unused build options
- Build more plugins

* Tue Mar 29 2011 Deji Akingunola <dakingun@gmail.com> - 3.8.1-5
- Rebuild for mpich2 soname bump

* Wed Oct 20 2010 Adam Jackson <ajax@redhat.com> 3.8.1-4
- Rebuild for new libOSMesa soname

* Thu Oct 7 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.1-3
- Remove any previous %%{_libdir}/paraview/paraview directories
  which prevent updates

* Tue Oct 5 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.1-2
- Disable install of third party libraries

* Fri Oct 1 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.1-1
- Update to 3.8.1
- Drop devel sub-package
- Drop installpath patch
- Drop hdf5-1.8 patch, build with hdf5 1.8 API
- Cleanup build

* Fri Jul 30 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.0-4
- Add patch to support python 2.7

* Tue Jul 27 2010 David Malcolm <dmalcolm@redhat.com> - 3.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jun 4 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.0-2
- Drop doc sub-package

* Tue Jun 1 2010 Orion Poplawski <orion@cora.nwra.com> - 3.8.0-1
- Update to 3.8.0
- Update demo patch
- Update hdf5 patch
- Drop old documentation patches
- Add patch to add needed include headers
- Add patch from upstream to fix install path issue

* Sat Mar 13 2010 Kevin Kofler <Kevin@tigcc.ticalc.org> - 3.6.2-4
- BR qt-assistant-adp-devel
- Don't Require qt4-assistant, should be qt-assistant-adp now, and it (or qt-x11
  4.6.x which Provides it) gets dragged in anyway by the soname dependencies

* Fri Feb 19 2010 Orion Poplawski <orion@cora.nwra.com> - 3.6.2-3
- More MPI packaging changes

* Tue Feb 16 2010 Orion Poplawski <orion@cora.nwra.com> - 3.6.2-2
- Conform to updated MPI packaging guidelines
- Build mpich2 version

* Mon Jan 4 2010 Orion Poplawski <orion@cora.nwra.com> - 3.6.2-1
- Update to 3.6.2

* Thu Nov 19 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-7
- New location for openmpi (fixes FTBFS bug #539179)

* Mon Aug 31 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-6
- Don't ship lproj, conflicts with vtk

* Thu Aug 27 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-5
- Specify PV_INSTALL_LIB_DIR as relative path, drop install prefix patch
- Update assitant patch to use assistant_adp, don't ship assistant-real

* Wed Aug 26 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-4
- Disable building various plugins that need OverView

* Tue Aug 25 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-3
- Disable building OverView - not ready yet

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 3.6.1-2
- rebuilt with new openssl

* Wed Jul 22 2009 Orion Poplawski <orion@cora.nwra.com> - 3.6.1-1
- Update to 3.6.1

* Thu May 7 2009 Orion Poplawski <orion@cora.nwra.com> - 3.4.0-5
- Update doc patch to look for help file in the right place (bug #499273)

* Tue Feb 24 2009 Orion Poplawski <orion@cora.nwra.com> - 3.4.0-4
- Rebuild with hdf5 1.8.2, gcc 4.4.0
- Update hdf5-1.8 patch to work with hdf5 1.8.2
- Add patch to allow build with Qt 4.5
- Move documentation into noarch sub-package

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 3.4.0-3
- rebuild with new openssl

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 3.4.0-2
- Rebuild for Python 2.6

* Fri Oct 17 2008 Orion Poplawski <orion@cora.nwra.com> - 3.4.0-1
- Update to 3.4.0 final

* Thu Oct 2 2008 Orion Poplawski <orion@cora.nwra.com> - 3.4.0-0.20081002.1
- Update 3.4.0 CVS snapshot
- Update gcc43 patch
- Drop qt patch, upstream now allows compiling against Qt 4.4.*

* Mon Aug 11 2008 Orion Poplawski <orion@cora.nwra.com> - 3.3.1-0.20080811.1
- Update 3.3.1 CVS snapshot
- Update hdf5 patch to drop upstreamed changes
- Fix mpi build (bug #450598)
- Use rpath instead of ls.so conf files so mpi and non-mpi can be installed at
  the same time
- mpi package now just ships mpi versions of the server components
- Drop useless mpi-devel subpackage
- Update hdf5 patch to fix H5pubconf.h -> H5public.h usage

* Wed May 20 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.3.0-0.20080520.1
- Update to 3.3.0 CVS snapshot
- Update qt and gcc43 patches, drop unneeded patches
- Add openssl-devel, gnuplot, and wget BRs
- Update license text filename
- Set VTK_USE_RPATH to off, needed with development versions
- Run ctest in %%check - still need to exclude more tests

* Wed Mar 5 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-5
- Rebuild for hdf5 1.8.0 using compatability API define and new patch

* Mon Feb 18 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-4
- Add patch to compile with gcc 4.3

* Fri Jan 18 2008 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-3
- Add patch to fix parallel make
- Obsolete demos package (bug #428528)

* Tue Dec 18 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-2
- Name ld.so.conf.d file with .conf extension
- Drop parallel make for now

* Mon Dec 03 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.2.1-1
- Update to 3.2.1
- Use macros for version numbers
- Add patches to fix documentation install location and use assistant-qt4,
  not install copies of Qt libraries, and not use rpath.
- Install ld.so.conf.d file
- Fixup desktop files

* Thu Aug 23 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.0.2-2
- Update license tag to BSD
- Fix make %%{_smp_mflags}
- Rebuild for ppc32

* Wed Jul 11 2007 - Orion Poplawski <orion@cora.nwra.com> - 3.0.2-1
- Update to 3.0.2
- Turn mpi build back on
- Add devel packages
- Remove demo package no longer in upstream
- Use cmake macros

* Thu Mar 08 2007 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-6
- Don't build mpi version until upstream fixes the build system

* Fri Dec 22 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-5
- Fix .so permissions
- Patch for const issue
- Patch for new cmake
- Build with openmpi

* Thu Dec 14 2006 - Jef Spaleta <jspaleta@gmail.com> - 2.4.4-4
- Bump and build for python 2.5

* Fri Oct  6 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-3
- Install needed python libraries to get around make install bug

* Wed Oct  4 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-2
- Re-enable OSMESA support for FC6
- Enable python wrapping

* Fri Sep 15 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.4-1
- Update to 2.4.4

* Thu Jun 29 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-8
- No OSMesa support in FC5
- Make data sub-package pull in main package (bug #193837)
- A patch from CVS to fix vtkXOpenRenderWindow.cxx
- Need lam-devel for FC6

* Fri Apr 21 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-7
- Re-enable ppc

* Mon Apr 17 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-6
- Exclude ppc due to gcc bug #189160

* Wed Apr 12 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-5
- Cleanup permissions

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-4
- Add icon and cleanup desktop file

* Mon Apr 10 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-3
- Add VTK_USE_MANGLE_MESA for off screen rendering
- Cleanup source permisions
- Add an initial .desktop file
- Make requirement on -data specific to version
- Don't package Ice-T man pages and cmake files

* Thu Apr  6 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-2
- Add mpi version

* Tue Apr  4 2006 - Orion Poplawski <orion@cora.nwra.com> - 2.4.3-1
- Initial Fedora Extras version
